/*
 * Copyright (c) 2009-2011 LodgON  (http://www.lodgon.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package com.lodgon.dali.core.ejb;

import javax.ejb.ApplicationException;

/**
 * This exception is used when DaliCore specific application logic has been
 * violated when persisting one of the DaliCore entities.
 *
 * @author erwin
 */
@ApplicationException
public class DaliCoreException extends Exception {
	/**
	 * All UUID's that are being used must be unique within one application for
	 * a specific DaliCore entity. If for instance a User is created with a
	 * uid that is already being used by another User, then a DaliCoreException
	 * will be thrown set with this type.
	 */
  public static final int UUID_CONFLICT = 10;

	/**
	 * All relations between DaliCore entities must be within the same application.
	 * If for instance a Group is created with a parent Group from a different
	 * application, then a DaliCoreException will be thrown set with this type.
	 */
  public static final int APPKEY_CONFLICT = 20;

	/**
	 * Sometimes it is required that a certain field is unique over all entities
	 * of the same type in order to let specific functionality work correctly. For
	 * instance, when validating a user by its screen name, it is required that
	 * the every user has a unique screen name.
	 */
  public static final int NON_UNIQUE = 30;
  
  /**
   * In case a specific permission is required for an operation, and in case 
   * that permission is not available, a DaliCoreException of this type
   * can be thrown. It is up to non-core implementations to decide what permission
   * checks need to be performed -- e.g. permissions to create a topic in 
   * a forum.
   */
  public static final int NO_PERMISSION = 40;

	private int type;

	/**
	 * Constructs a <code>DaliCoreException</code> with no detail message.
	 */
  public DaliCoreException() {
  }

	/**
	 * Constructs a <code>DaliCoreException</code> with the specified detail message.
	 *
	 * @param message the detail message
	 */
  public DaliCoreException(String message) {
    super(message);
  }

	/**
	 * Constructs a <code>DaliCoreException</code> with the specified type and detail message.
	 *
	 * @param type the type
	 * @param message the detail message
	 */
  public DaliCoreException(int type, String message) {
    super(message);
    this.type = type;
  }

	/**
	 * Returns the type of DaliCoreException.
	 *
	 * @return The type of this DaliCoreException instance, which can be 0.
	 */
  public int getType() {
    return type;
  }
}
