/*
 * Copyright (c) 2009-2011 LodgON  (http://www.lodgon.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package com.lodgon.dali.core.entity.search;

import com.lodgon.dali.core.entity.Content;
import com.lodgon.dali.core.entity.Group;
import com.lodgon.dali.core.entity.User;

/**
 * Builder class for {@link com.lodgon.dali.core.entity.search.ContentSearchParams}.
 *
 * @author joeri
 */
public class ContentSearchParamsBuilder extends ParentSearchParamsBuilder<ContentSearchParamsBuilder, ContentSearchParams, Content> {
	public ContentSearchParamsBuilder() {
		this.params = new ContentSearchParams();
	}

	/**
	 * Sets the {@link com.lodgon.dali.core.entity.search.ContentSearchParams#setAuthor(com.lodgon.dali.core.entity.User) author}
	 * property for the instance constructed by this builder.
	 */
	public ContentSearchParamsBuilder author(User author) {
		params.setAuthor(author);
		params.setAuthorId(null);
		return this;
	}

	/**
	 * Sets the {@link com.lodgon.dali.core.entity.search.ContentSearchParams#setAuthorId(java.lang.Integer) authorId}
	 * property for the instance constructed by this builder.
	 */
	public ContentSearchParamsBuilder authorId(Integer authorId) {
		params.setAuthorId(authorId);
		params.setAuthor(null);
		return this;
	}

	/**
	 * Adds a value to the {@link com.lodgon.dali.core.entity.search.ContentSearchParams#setContents(java.util.Set) contents}
	 * property for the instance constructed by this builder.
	 */
	public ContentSearchParamsBuilder content(String content) {
		params.getContents().add(content);
		return this;
	}

	/**
	 * Sets the {@link com.lodgon.dali.core.entity.search.ContentSearchParams#setGroup(com.lodgon.dali.core.entity.Group) group}
	 * property for the instance constructed by this builder.
	 */
	public ContentSearchParamsBuilder group(Group group) {
		params.setGroup(group);
		params.setGroupId(null);
		return this;
	}

	/**
	 * Sets the {@link com.lodgon.dali.core.entity.search.ContentSearchParams#setGroupId(java.lang.Integer) groupId}
	 * property for the instance constructed by this builder.
	 */
	public ContentSearchParamsBuilder groupId(Integer groupId) {
		params.setGroupId(groupId);
		params.setGroup(null);
		return this;
	}

	/**
	 * Adds a value to the {@link com.lodgon.dali.core.entity.search.ContentSearchParams#setSummaries(java.util.Set) summaries}
	 * property for the instance constructed by this builder.
	 */
	public ContentSearchParamsBuilder summary(String summary) {
		params.getSummaries().add(summary);
		return this;
	}

	/**
	 * Adds a value to the {@link com.lodgon.dali.core.entity.search.ContentSearchParams#setTags(java.util.Set) tags}
	 * property for the instance constructed by this builder.
	 */
	public ContentSearchParamsBuilder tag(String tag) {
		params.getTags().add(tag);
		return this;
	}

	/**
	 * Adds a value to the {@link com.lodgon.dali.core.entity.search.ContentSearchParams#setTitles(java.util.Set) titles}
	 * property for the instance constructed by this builder.
	 */
	public ContentSearchParamsBuilder title(String title) {
		params.getTitles().add(title);
		return this;
	}
}
