/*
 * Copyright (c) 2009-2011 LodgON  (http://www.lodgon.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package com.lodgon.dali.core.entity.search;

import com.lodgon.dali.core.entity.Group;
import com.lodgon.dali.core.entity.User;

/**
 * Builder class for {@link com.lodgon.dali.core.entity.search.GroupSearchParams}.
 *
 * @author joeri
 */
public class GroupSearchParamsBuilder extends ParentSearchParamsBuilder<GroupSearchParamsBuilder, GroupSearchParams, Group> {
	public GroupSearchParamsBuilder() {
		this.params = new GroupSearchParams();
	}

	/**
	 * Sets the {@link com.lodgon.dali.core.entity.search.GroupSearchParams#setAuthor(com.lodgon.dali.core.entity.User) author}
	 * property for the instance constructed by this builder.
	 */
	public GroupSearchParamsBuilder author(User author) {
		params.setAuthor(author);
		params.setAuthorId(null);
		return this;
	}

	/**
	 * Sets the {@link com.lodgon.dali.core.entity.search.GroupSearchParams#setAuthorId(java.lang.Integer) authorId}
	 * property for the instance constructed by this builder.
	 */
	public GroupSearchParamsBuilder authorId(Integer authorId) {
		params.setAuthorId(authorId);
		params.setAuthor(null);
		return this;
	}

	/**
	 * Sets the {@link com.lodgon.dali.core.entity.search.GroupSearchParams#setMember(com.lodgon.dali.core.entity.User) member}
	 * property for the instance constructed by this builder.
	 */
	public GroupSearchParamsBuilder member(User member) {
		params.setMember(member);
		params.setMemberId(null);
		return this;
	}

	/**
	 * Sets the {@link com.lodgon.dali.core.entity.search.GroupSearchParams#setMemberId(java.lang.Integer) memberId}
	 * property for the instance constructed by this builder.
	 */
	public GroupSearchParamsBuilder memberId(Integer memberId) {
		params.setMemberId(memberId);
		params.setMember(null);
		return this;
	}

	/**
	 * Adds a value to the {@link com.lodgon.dali.core.entity.search.GroupSearchParams#setNames(java.util.Set) names}
	 * property for the instance constructed by this builder.
	 */
	public GroupSearchParamsBuilder name(String name) {
		params.getNames().add(name);
		return this;
	}
}
