/*
 * Copyright (c) 2009-2011 LodgON  (http://www.lodgon.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package com.lodgon.dali.core.entity.search;

/**
 * The base class for building instances of ParentSearchParams using the builder
 * pattern.
 *
 * @author joeri
 */
public abstract class ParentSearchParamsBuilder<T extends ParentSearchParamsBuilder, U extends ParentSearchParams, V> extends SearchParamsBuilder<T, U> {
	/**
	 * Sets the {@link com.lodgon.dali.core.entity.search.ParentSearchParams#setDepth(java.lang.Integer) depth}
	 * property for the instance constructed by this builder.
	 */
	public T depth(Integer depth) {
		params.setDepth(depth);
		return (T) this;
	}

	/**
	 * Sets the {@link com.lodgon.dali.core.entity.search.ParentSearchParams#setParent(java.lang.Object) parent}
	 * property for the instance constructed by this builder.
	 */
	public T parent(V parent) {
		params.setParent(parent);
		params.setParentId(null);
		return (T) this;
	}

	/**
	 * Sets the {@link com.lodgon.dali.core.entity.search.ParentSearchParams#setParentId(java.lang.Integer) parentId}
	 * property for the instance constructed by this builder.
	 */
	public T parentId(Integer parent) {
		params.setParentId(parent);
		params.setParent(null);
		return (T) this;
	}
}
