/*
 * Copyright (c) 2009-2011 LodgON  (http://www.lodgon.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package com.lodgon.dali.core.entity.search;

import com.lodgon.dali.core.entity.Group;
import com.lodgon.dali.core.entity.Status;
import java.util.HashSet;
import java.util.Set;

/**
 * Bundles all the parameters that can be used to search the DaliCore user store.
 *
 * @author joeri
 */
public class UserSearchParams extends SearchParams {
	private Set<String> emails = new HashSet<String>();
  private Set<String> firstNames = new HashSet<String>();
	private Set<Group> groups = new HashSet<Group>();
	private Set<Integer> groupIds = new HashSet<Integer>();
  private Set<String> lastNames = new HashSet<String>();
  private Set<String> screenNames = new HashSet<String>();
	private Set<Status> statuses = new HashSet<Status>();

	/**
	 * The list of e-mail addresses to search by.
	 *
	 * @return the list of e-mail addresses to search by
	 */
	public Set<String> getEmails() {
		return emails;
	}

	/**
	 * Defines the list of e-mail addresses to search by. You can use * as a
	 * wildcard.
	 *
	 * @param emails a list of e-mail addresses to search by
	 */
	public void setEmails(Set<String> emails) {
		this.emails = emails;
	}

	/**
	 * The list of first names to search by.
	 *
	 * @return the list of first names to search by
	 */
	public Set<String> getFirstNames() {
		return firstNames;
	}

	/**
	 * Defines the list of first names to search by. You can use * as a wildcard.
	 *
	 * @param firstNames a list of first names to search by
	 */
	public void setFirstNames(Set<String> firstNames) {
		this.firstNames = firstNames;
	}

	/**
	 * The list of id's of Group entities where the user belongs to.
	 *
	 * @return a list of id's of Group entities the user belongs to
	 */
	public Set<Integer> getGroupIds() {
		return groupIds;
	}

	/**
	 * Defines the list of id's of Group entities where the user belongs to.
	 *
	 * @param groupIds a list of id's of Group entities the user belongs to
	 */
	public void setGroupIds(Set<Integer> groupIds) {
		this.groupIds = groupIds;
	}

	/**
	 * The list of managed Group entities where the user belongs to.
	 *
	 * @return a list of managed Group entities the user belongs to
	 */
	public Set<Group> getGroups() {
		return groups;
	}

	/**
	 * Defines the list of managed Group entities where the user belongs to.
	 *
	 * @param groups a list of managed Group entities the user belongs to
	 */
	public void setGroups(Set<Group> groups) {
		this.groups = groups;
	}

	/**
	 * The list of last names to search by.
	 *
	 * @return the list of last names to search by
	 */
	public Set<String> getLastNames() {
		return lastNames;
	}

	/**
	 * Defines the list of last names to search by. You can use * as a wildcard.
	 *
	 * @param lastNames a list of last names to search by
	 */
	public void setLastNames(Set<String> lastNames) {
		this.lastNames = lastNames;
	}

	/**
	 * The list of screen names to search by.
	 *
	 * @return the list of screen names to search by
	 */
	public Set<String> getScreenNames() {
		return screenNames;
	}

	/**
	 * Defines the list of screen names to search by. You can use * as a wildcard.
	 *
	 * @param screenNames a list of screen names to search by
	 */
	public void setScreenNames(Set<String> screenNames) {
		this.screenNames = screenNames;
	}

	/**
	 * The list of statuses to search by.
	 *
	 * @return the list of statuses to search by
	 */
	public Set<Status> getStatuses() {
		return statuses;
	}

	/**
	 * Defines the list of statuses to search by. If no statuses are specified,
	 * then the search will only return users with status {@link com.lodgon.dali.core.entity.Status#ACTIVE}
	 * and {@link com.lodgon.dali.core.entity.Status#BLOCKED}.
	 *
	 * @param statuses a list of statuses to search by
	 */
	public void setStatuses(Set<Status> statuses) {
		this.statuses = statuses;
	}
}
