/*
 * Copyright (c) 2009-2011 LodgON  (http://www.lodgon.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package com.lodgon.dali.core.entity.search;

import com.lodgon.dali.core.entity.Group;
import com.lodgon.dali.core.entity.Status;

/**
 * Builder class for {@link com.lodgon.dali.core.entity.search.UserSearchParams}.
 *
 * @author joeri
 */
public class UserSearchParamsBuilder extends SearchParamsBuilder<UserSearchParamsBuilder, UserSearchParams> {
	public UserSearchParamsBuilder() {
		this.params = new UserSearchParams();
	}

	/**
	 * Adds value to the {@link com.lodgon.dali.core.entity.search.UserSearchParams#setEmails(java.util.Set) emails}
	 * property for the instance constructed by this builder.
	 */
	public UserSearchParamsBuilder email(String email) {
		params.getEmails().add(email);
		return this;
	}

	/**
	 * Adds a value to the {@link com.lodgon.dali.core.entity.search.UserSearchParams#setFirstNames(java.util.Set) firstNames}
	 * property for the instance constructed by this builder.
	 */
	public UserSearchParamsBuilder firstName(String firstName) {
		params.getFirstNames().add(firstName);
		return this;
	}

	/**
	 * Adds a value to the {@link com.lodgon.dali.core.entity.search.UserSearchParams#setGroups(java.util.Set) groups}
	 * property for the instance constructed by this builder.
	 */
	public UserSearchParamsBuilder group(Group group) {
		params.getGroups().add(group);
		params.getGroupIds().clear();
		return this;
	}

	/**
	 * Adds a value to the {@link com.lodgon.dali.core.entity.search.UserSearchParams#setGroupIds(java.util.Set) groupIds}
	 * property for the instance constructed by this builder.
	 */
	public UserSearchParamsBuilder groupId(Integer groupId) {
		params.getGroupIds().add(groupId);
		params.getGroups().clear();
		return this;
	}

	/**
	 * Adds a value to the {@link com.lodgon.dali.core.entity.search.UserSearchParams#setLastNames(java.util.Set) lastNames}
	 * property for the instance constructed by this builder.
	 */
	public UserSearchParamsBuilder lastName(String lastName) {
		params.getLastNames().add(lastName);
		return this;
	}

	/**
	 * Adds a value to the {@link com.lodgon.dali.core.entity.search.UserSearchParams#setScreenNames(java.util.Set) screenNames}
	 * property for the instance constructed by this builder.
	 */
	public UserSearchParamsBuilder screenName(String screenName) {
		params.getScreenNames().add(screenName);
		return this;
	}

	/**
	 * Adds a value to the {@link com.lodgon.dali.core.entity.search.UserSearchParams#setStatuses(java.util.Set) statuses}
	 * property for the instance constructed by this builder.
	 */
	public UserSearchParamsBuilder status(Status status) {
		params.getStatuses().add(status);
		return this;
	}
}
