/*
 * Copyright (c) 2009-2011 LodgON  (http://www.lodgon.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package com.lodgon.dali.core.search;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;
import javax.inject.Qualifier;

/**
 * A CDI qualifier for events that are fired when a DaliCore entity is being
 * persisted, updated or removed. Event consumers can observe three types of
 * events: ActionType.CREATE, ActionType.UPDATE and ActionType.DELETE.
 *
 * For instance, to listen for the event that is fired when a User entity gets
 * persisted, you can use the following code:
 *
 * <pre>
 *   void userPersisted(@Observes(during=TransactionPhase.AFTER_SUCCESS) @EntityAction(ActionType.CREATE) User user) {
 *     System.out.println("User persisted with id " + user.getId());
 *   }
 * </pre>
 *
 * Please note that we use TransactionPhase.AFTER_SUCCESS to make sure that we
 * only receive an event after a User was successfully persisted.
 *
 * @author Joeri
 */
@Qualifier
@Retention(RetentionPolicy.RUNTIME)
@Target({ElementType.METHOD, ElementType.FIELD, ElementType.PARAMETER, ElementType.TYPE})
public @interface EntityAction {
	ActionType value();
}
